@@ -8,11 +8,11 @@ master_doc = 'index'
 project = u'sphinx theme for basicstrap style'
 copyright = u'2013, tell-k'
 
-version = '0.3.1'
+version = '0.3.2'
 
 # -- Options for HTML output ---------------------------------------------------
 
-extensions = ['sphinxjp.themecore']
+extensions = ['sphinxjp.themes.basicstrap']
 html_theme = 'basicstrap'
 
 # -- HTML theme options for `basicstrap` style -------------------------------------
@@ -35,10 +35,10 @@ html_theme_options = {
     'relbar_inverse': False,
     'inner_theme': True,
     'inner_theme_name': 'bootswatch-flatly',
-    'h1_size': '3.0em',
-    'h2_size': '2.6em',
-    'h3_size': '2.2em',
-    'h4_size': '1.8em',
-    'h5_size': '1.4em',
-    'h6_size': '1.1em',
+#    'h1_size': '3.0em',
+#    'h2_size': '2.6em',
+#    'h3_size': '2.2em',
+#    'h4_size': '1.8em',
+#    'h5_size': '1.4em',
+#    'h6_size': '1.1em',
 }
